@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2021 Aspose.Cells Cloud
+Copyright (c) 2022 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -182,6 +182,153 @@ __PACKAGE__->method_documentation({
     	format => '',
     	read_only => '',
     		},
+    'save_as_single_file' => {
+    	datatype => 'string',
+    	base_name => 'SaveAsSingleFile',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_hidden_worksheet' => {
+    	datatype => 'string',
+    	base_name => 'ExportHiddenWorksheet',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_grid_lines' => {
+    	datatype => 'string',
+    	base_name => 'ExportGridLines',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'presentation_preference' => {
+    	datatype => 'string',
+    	base_name => 'PresentationPreference',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'cell_css_prefix' => {
+    	datatype => 'string',
+    	base_name => 'CellCssPrefix',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'table_css_id' => {
+    	datatype => 'string',
+    	base_name => 'TableCssId',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'is_full_path_link' => {
+    	datatype => 'string',
+    	base_name => 'IsFullPathLink',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_worksheet_css_separately' => {
+    	datatype => 'string',
+    	base_name => 'ExportWorksheetCSSSeparately',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_similar_border_style' => {
+    	datatype => 'string',
+    	base_name => 'ExportSimilarBorderStyle',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'merge_empty_td_forcely' => {
+    	datatype => 'string',
+    	base_name => 'MergeEmptyTdForcely',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_cell_coordinate' => {
+    	datatype => 'string',
+    	base_name => 'ExportCellCoordinate',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_extra_headings' => {
+    	datatype => 'string',
+    	base_name => 'ExportExtraHeadings',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_headings' => {
+    	datatype => 'string',
+    	base_name => 'ExportHeadings',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_formula' => {
+    	datatype => 'string',
+    	base_name => 'ExportFormula',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'add_tooltip_text' => {
+    	datatype => 'string',
+    	base_name => 'AddTooltipText',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_bogus_row_data' => {
+    	datatype => 'string',
+    	base_name => 'ExportBogusRowData',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'exclude_unused_styles' => {
+    	datatype => 'string',
+    	base_name => 'ExcludeUnusedStyles',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_document_properties' => {
+    	datatype => 'string',
+    	base_name => 'ExportDocumentProperties',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_worksheet_properties' => {
+    	datatype => 'string',
+    	base_name => 'ExportWorksheetProperties',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_workbook_properties' => {
+    	datatype => 'string',
+    	base_name => 'ExportWorkbookProperties',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
+    'export_frame_scripts_and_properties' => {
+    	datatype => 'string',
+    	base_name => 'ExportFrameScriptsAndProperties',
+    	description => '',
+    	format => '',
+    	read_only => '',
+    		},
     'attached_files_directory' => {
     	datatype => 'string',
     	base_name => 'AttachedFilesDirectory',
@@ -277,6 +424,27 @@ __PACKAGE__->swagger_types( {
     'refresh_chart_cache' => 'boolean',
     'create_directory' => 'boolean',
     'sort_names' => 'boolean',
+    'save_as_single_file' => 'string',
+    'export_hidden_worksheet' => 'string',
+    'export_grid_lines' => 'string',
+    'presentation_preference' => 'string',
+    'cell_css_prefix' => 'string',
+    'table_css_id' => 'string',
+    'is_full_path_link' => 'string',
+    'export_worksheet_css_separately' => 'string',
+    'export_similar_border_style' => 'string',
+    'merge_empty_td_forcely' => 'string',
+    'export_cell_coordinate' => 'string',
+    'export_extra_headings' => 'string',
+    'export_headings' => 'string',
+    'export_formula' => 'string',
+    'add_tooltip_text' => 'string',
+    'export_bogus_row_data' => 'string',
+    'exclude_unused_styles' => 'string',
+    'export_document_properties' => 'string',
+    'export_worksheet_properties' => 'string',
+    'export_workbook_properties' => 'string',
+    'export_frame_scripts_and_properties' => 'string',
     'attached_files_directory' => 'string',
     'attached_files_url_prefix' => 'string',
     'encoding' => 'string',
@@ -300,6 +468,27 @@ __PACKAGE__->attribute_map( {
     'refresh_chart_cache' => 'RefreshChartCache',
     'create_directory' => 'CreateDirectory',
     'sort_names' => 'SortNames',
+    'save_as_single_file' => 'SaveAsSingleFile',
+    'export_hidden_worksheet' => 'ExportHiddenWorksheet',
+    'export_grid_lines' => 'ExportGridLines',
+    'presentation_preference' => 'PresentationPreference',
+    'cell_css_prefix' => 'CellCssPrefix',
+    'table_css_id' => 'TableCssId',
+    'is_full_path_link' => 'IsFullPathLink',
+    'export_worksheet_css_separately' => 'ExportWorksheetCSSSeparately',
+    'export_similar_border_style' => 'ExportSimilarBorderStyle',
+    'merge_empty_td_forcely' => 'MergeEmptyTdForcely',
+    'export_cell_coordinate' => 'ExportCellCoordinate',
+    'export_extra_headings' => 'ExportExtraHeadings',
+    'export_headings' => 'ExportHeadings',
+    'export_formula' => 'ExportFormula',
+    'add_tooltip_text' => 'AddTooltipText',
+    'export_bogus_row_data' => 'ExportBogusRowData',
+    'exclude_unused_styles' => 'ExcludeUnusedStyles',
+    'export_document_properties' => 'ExportDocumentProperties',
+    'export_worksheet_properties' => 'ExportWorksheetProperties',
+    'export_workbook_properties' => 'ExportWorkbookProperties',
+    'export_frame_scripts_and_properties' => 'ExportFrameScriptsAndProperties',
     'attached_files_directory' => 'AttachedFilesDirectory',
     'attached_files_url_prefix' => 'AttachedFilesUrlPrefix',
     'encoding' => 'Encoding',
